@@ -2,12 +2,12 @@ package Net::DNS::DynDNS;
 
 use warnings;
 use strict;
-use LWP();
+use LWP::UserAgent();
 use HTTP::Cookies();
 use HTTP::Headers();
 use Carp();
 use English qw(-no_match_vars);
-our $VERSION = '0.9992';
+our $VERSION = '0.9994';
 
 our @CARP_NOT = ('Net::DNS::DynDNS');
 sub DEFAULT_TIMEOUT                      { return 60 }
@@ -43,7 +43,7 @@ sub new {
             Carp::croak(q[The 'timeout' parameter must be a number]);
         }
     }
-    my $name = "Net::DNS::DynDNS $VERSION "
+    my $name = "Net-DNS-DynDNS/$VERSION "
       ;    # a space causes the default LWP User Agent to be appended.
     if ( exists $params->{user_agent} ) {
         if ( ( $params->{user_agent} ) && ( $params->{user_agent} =~ /\S/xsm ) )
@@ -150,11 +150,6 @@ sub _check_ip_address_uri {
         }
         $protocol = $params->{protocol};
     }
-    if ( $protocol eq 'https' ) {
-        eval { require Net::HTTPS; } or do {
-            Carp::croak(q[Cannot load Net::HTTPS]);
-        };
-    }
     return $protocol . '://' . $self->{check_ip};
 }
 
@@ -416,11 +411,6 @@ sub update {
     if ( $params->{protocol} ) {
         $protocol = $params->{protocol};
     }
-    if ( $protocol eq 'https' ) {
-        eval { require Net::HTTPS; } or do {
-            Carp::croak(q[Cannot load Net::HTTPS]);
-        };
-    }
     my $update_uri =
       $protocol . "://$self->{dns_server}/nic/update?hostname=" . $hostnames;
     if ( defined $ip_address ) {
@@ -506,7 +496,7 @@ Net::DNS::DynDNS - Update dyndns.org with correct ip address for your domain nam
 
 =head1 VERSION
  
-Version 0.9992
+Version 0.9993
 
 =head1 SYNOPSIS
 
@@ -521,13 +511,13 @@ off dynamic ip addresses.
 
 =head1 SUBROUTINES/METHODS
 
-=item default_ip_address
+=head2 default_ip_address
 
 returns your current ip address according to dyndns.org.  This function should
 not be used more than once every 10 minutes according to terms of usage for
 dyndns.org.
 
-=item new( $username, $password, $params )
+=head2 new( $username, $password, $params )
 
 returns a new object for updating dyndns.org entries.  The username and password
 parameters are from your dyndns.org account.
@@ -537,7 +527,7 @@ parameters are from your dyndns.org account.
    dns_server           members.dyndns.org
    check_ip             checkip.dyndns.org
 
-=item update_allowed ( $setting )
+=head2 update_allowed ( $setting )
 
 returns whether the object is permitted to make another update to dyndns.org without 
 human intervention.  There are a list of return codes at 
@@ -545,7 +535,7 @@ http://www.dyndns.org/developers/specs/return.html that require this behaviour.
 signal that human intervention has allowed updating to continue, pass a true value 
 in the parameter list.
 
-=item update( $hostnames, $ip_address, $params )
+=head2 update( $hostnames, $ip_address, $params )
 
 returns the ip address that has been assigned to the hostnames.  The hostnames should be
 fully qualified domain names.  If there is more than one hostname to be updated, they should
@@ -578,7 +568,7 @@ Net::DNS::DynDNS requires the following non-core Perl modules
 L<LWP|LWP>
  
 =item *
-L<Net::HTTPS|Net::HTTPS>
+L<LWP::Protocol::https|LWP::Protocol::https>
  
 =item *
 L<HTTP::Cookies|HTTP::Cookies>
@@ -586,13 +576,15 @@ L<HTTP::Cookies|HTTP::Cookies>
 =item *
 L<HTTP::Headers|HTTP::Headers>
 
+=back
+
 =head1 INCOMPATIBILITIES
  
 None reported
 
 =head1 AUTHOR
 
-David Dick <ddick@cpan.org>
+David Dick, C<< <ddick at cpan.org> >>
 
 =head1 BUGS AND LIMITATIONS
 
